<img src="docs/logo.png" width="322" alt="django-scarface" />
-----------

Send push notifications to mobile devices using Amazon SNS

[![Documentation Status](https://readthedocs.org/projects/django-scarface/badge/?version=latest)](https://readthedocs.org/projects/django-scarface/?badge=latest)
[![Build Status](https://travis-ci.org/dreipol/django-scarface.svg?branch=master)](https://travis-ci.org/dreipol/django-scarface)

Documentation
-----------
https://django-scarface.readthedocs.io/

Changelog
------------
https://github.com/dreipol/django-scarface/blob/master/CHANGELOG.MD

Project Home
------------
https://github.com/dreipol/django-scarface

PyPi
------------
https://pypi.python.org/pypi/django-scarface


Contributors
------------
[@browniebroke](https://github.com/browniebroke)
[@kennydude](https://github.com/kennydude)
[@nanorepublica](https://github.com/nanorepublica)
[@J0hn5mith](https://github.com/J0hn5mith)
[@philipplaeubli](https://github.com/philipplaeubli)
[@neosergio](https://github.com/neosergio)
[@melbic](https://github.com/melbic)

and many more...

Trivia
------------
django-scarface is named after the track ‘Push it to the Limit’ featured in the movie Scarface (1983).

![Scarface the movie (1983)](docs/scarface-movie.png "Scarface the movie (1983)")
